@@ -3,12 +3,13 @@
 ###########                           Alteraes feitas em 03/05/2010 por Celso Rmulo              ################
 ###########                           Esta  a verso utilizada no artigo submetido ao CSDA         ################
 smsn.mmix <- function(y, nu=1, mu = NULL, Sigma = NULL, shape = NULL, pii = NULL, g = NULL, get.init = TRUE, criteria = TRUE,
-                      group = FALSE, family = "Skew.normal", error = 0.0001, iter.max = 100, uni.Gama = FALSE){#, calc.imm=TRUE){
+                      group = FALSE, family = "Skew.normal", error = 0.0001, iter.max = 100, uni.Gama = FALSE, calc.im=FALSE){
   #mu, Sigma, shape devem ser do tipo list(). O numero de entradas no list  o numero g de componentes de misturas
   #cada entrada do list deve ser de tamanho igual ao numero de colunas da matriz de dados y
   y <- as.matrix(y)
   dimnames(y) <- NULL
   if(!is.matrix(y)) stop("The response is not in a matrix format\n")
+  if(ncol(p) <= 1) stop("For the univariate case use the smsn.mix function\n")
   if((family != "Skew.t") && (family != "Skew.cn") && (family != "Skew.slash") && (family != "Skew.normal") && (family != "Normal")) stop(paste("Family",family,"not recognized.",sep=" "))
   if((length(g) == 0) && ((length(mu)==0) || (length(Sigma)==0) || (length(shape)==0) || (length(pii)==0)))  stop("The model is not specified correctly.\n")
   if(get.init == FALSE){
@@ -662,12 +663,11 @@ smsn.mmix <- function(y, nu=1, mu = NULL, Sigma = NULL, shape = NULL, pii = NULL
      obj.out$uni.Gama <- uni.Gama
      class(obj.out) <- family
 
-#     if(calc.imm){
-#        IM <-  imm.smsn(as.matrix(y), obj.out)
-#        sdev <- sqrt(diag(solve(IM$IM)))
-#        obj.out$imm.sdev = sdev
-#     }
-
+     if(calc.im){
+        IM <-  imm.smsn(as.matrix(y), obj.out)
+        sdev <- sqrt(diag(solve(IM$IM)))
+        obj.out$imm.sdev = sdev
+     }
      class(obj.out) <- family
      
  obj.out
